@@ -1,18 +1,21 @@
 package Perinci::CmdLine::Dump;
 
-our $DATE = '2016-10-27'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2017-01-07'; # DATE
+our $VERSION = '0.07'; # VERSION
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 
 use Exporter qw(import);
-our @EXPORT_OK = qw(dump_perinci_cmdline_script);
+our @EXPORT_OK = qw(
+                       dump_pericmd_script
+                       dump_perinci_cmdline_script
+               );
 
 our %SPEC;
 
-$SPEC{dump_perinci_cmdline_script} = {
+$SPEC{dump_pericmd_script} = {
     v => 1.1,
     summary => 'Run a Perinci::CmdLine-based script but only to '.
         'dump the object',
@@ -61,7 +64,7 @@ _
         },
     },
 };
-sub dump_perinci_cmdline_script {
+sub dump_pericmd_script {
     require Capture::Tiny;
     require Perinci::CmdLine::Util;
     require Scalar::Util;
@@ -160,6 +163,12 @@ do "$filename";
     $res;
 }
 
+{
+    no strict 'refs';
+    # old name, deprecated
+    *dump_perinci_cmdline_script = \&dump_pericmd_script;
+}
+
 1;
 # ABSTRACT: Run a Perinci::CmdLine-based script but only to dump the object
 
@@ -175,12 +184,14 @@ Perinci::CmdLine::Dump - Run a Perinci::CmdLine-based script but only to dump th
 
 =head1 VERSION
 
-This document describes version 0.06 of Perinci::CmdLine::Dump (from Perl distribution Perinci-CmdLine-Dump), released on 2016-10-27.
+This document describes version 0.07 of Perinci::CmdLine::Dump (from Perl distribution Perinci-CmdLine-Dump), released on 2017-01-07.
+
+=for Pod::Coverage ^(dump_perinci_cmdline_script)$
 
 =head1 FUNCTIONS
 
 
-=head2 dump_perinci_cmdline_script(%args) -> [status, msg, result, meta]
+=head2 dump_pericmd_script(%args) -> [status, msg, result, meta]
 
 Run a Perinci::CmdLine-based script but only to dump the object.
 
@@ -240,7 +251,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Base-Patch-DumpAndExit>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Dump>.
 
 =head1 BUGS
 
@@ -256,7 +267,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
